loadingPlaceholder property
A widget rendered when the image is not ready. Default is const CircularProgressIndicator.adaptive()
Implementation
final Widget loadingPlaceholder;
A widget rendered when the image is not ready. Default is const CircularProgressIndicator.adaptive()
final Widget loadingPlaceholder;