minImageScale property
Minimum image scale in CropInteractionMode.panZoomImage.
Values below 1 are allowed; the effective minimum is raised so the image always covers the crop frame.
Implementation
final double minImageScale;
Minimum image scale in CropInteractionMode.panZoomImage.
Values below 1 are allowed; the effective minimum is raised so the image always covers the crop frame.
final double minImageScale;