overlayWidget property
An optional widget between the image and the crop grid.
Can be used to display any kind of widget on top of the image.
Implementation
final Widget? overlayWidget;
An optional widget between the image and the crop grid.
Can be used to display any kind of widget on top of the image.
final Widget? overlayWidget;