CropRotation enum
90 degree rotations.
- Inheritance
- Available extensions
Values
- up → const CropRotation
- right → const CropRotation
- down → const CropRotation
- left → const CropRotation
Properties
- degrees → int
-
Available on CropRotation, provided by the CropRotationExtension extension
Returns the rotation in degrees cw.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isSideways → bool
-
Available on CropRotation, provided by the CropRotationExtension extension
Returns true if the rotated width is the initial height.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - radians → double
-
Available on CropRotation, provided by the CropRotationExtension extension
Returns the rotation in radians cw.no setter - rotateLeft → CropRotation
-
Available on CropRotation, provided by the CropRotationExtension extension
Returns the rotation rotated 90 degrees to the left.no setter - rotateRight → CropRotation
-
Available on CropRotation, provided by the CropRotationExtension extension
Returns the rotation rotated 90 degrees to the right.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getRotatedOffset(
Offset offset01, double straightWidth, double straightHeight) → Offset -
Available on CropRotation, provided by the CropRotationExtension extension
Returns the offset as rotated. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CropRotation> - A constant List of the values in this enum, in order of their declaration.