CropControllerValue class
- Annotations
Constructors
- CropControllerValue(double? aspectRatio, Rect crop, CropRotation rotation, double minimumImageSize)
-
const
Properties
- aspectRatio → double?
-
final
- crop → Rect
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- minimumImageSize → double
-
final
- rotation → CropRotation
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? aspectRatio, Rect? crop, CropRotation? rotation, double? minimumImageSize}) → CropControllerValue -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override