CropImagePro class

Widget to crop images.

See also:

Inheritance

Constructors

CropImagePro({Key? key, CropController? controller, required Image image, Color gridColor = Colors.white70, Color? gridInnerColor, Color? gridCornerColor, double paddingSize = 0, double touchSize = 50, double gridCornerSize = 25, double cornerOffset = 0, bool showCorners = true, double gridThinWidth = 2, double gridThickWidth = 5, Color scrimColor = Colors.black54, bool alwaysShowThirdLines = false, ValueChanged<Rect>? onCrop, double minimumImageSize = 100, double maximumImageSize = double.infinity, bool alwaysMove = false, CropInteractionMode interactionMode = CropInteractionMode.panZoomImage, double minImageScale = 1.0, double maxImageScale = 4.0, CustomPainter? overlayPainter, Widget? overlayWidget, Widget loadingPlaceholder = const CircularProgressIndicator.adaptive()})
const

Properties

alwaysMove bool
When true, moves when panning beyond corners, even beyond the crop rect. When false, moves when panning beyond corners but inside the crop rect.
final
alwaysShowThirdLines bool
True if third lines of the crop grid are always displayed. False if third lines are only displayed while the user manipulates the grid.
final
controller CropController?
Controls the crop values being applied.
final
cornerOffset double
The offset of the corner handles from the crop grid edges.
final
gridColor Color
The crop grid color of the outer lines.
final
gridCornerColor Color
The crop grid color of the corner lines.
final
gridCornerSize double
The size of the corner of the crop grid.
final
gridInnerColor Color
The crop grid color of the inner lines.
final
gridThickWidth double
The width of the crop grid thick lines.
final
gridThinWidth double
The width of the crop grid thin lines.
final
hashCode int
The hash code for this object.
no setterinherited
image Image
The image to be cropped.
final
interactionMode CropInteractionMode
How the user interacts with the crop UI.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingPlaceholder Widget
A widget rendered when the image is not ready. Default is const CircularProgressIndicator.adaptive()
final
maxImageScale double
Maximum image scale in CropInteractionMode.panZoomImage.
final
maximumImageSize double
The maximum pixel size the crop rectangle can be grown to.
final
minImageScale double
Minimum image scale in CropInteractionMode.panZoomImage.
final
minimumImageSize double
The minimum pixel size the crop rectangle can be shrunk to.
final
onCrop ValueChanged<Rect>?
Event called when the user changes the crop rectangle.
final
overlayPainter CustomPainter?
An optional painter between the image and the crop grid.
final
overlayWidget Widget?
An optional widget between the image and the crop grid.
final
paddingSize double
The size of the padding around the image and crop grid.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrimColor Color
The crop grid scrim (outside area overlay) color.
final
showCorners bool
Whether to display the corners.
final
touchSize double
The size of the touch area.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CropImagePro>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited